@@ -19,7 +19,7 @@ function(series1,series2,max.lag=0,corr=TRUE,smooth=TRUE,col=gray(.1),
    pcol=ceiling(m1/prow)
    a=stats::ccf(series1,series2,max.lag,plot=FALSE)$acf
    old.par <- par(no.readonly = TRUE)
-   par(mfrow=c(prow,pcol))#,  mar=c(2.5, 2.5, 1, 1), mgp=c(1.6,.6,0), cex.main=1, font.main=1)
+   par(mfrow=c(prow,pcol))
    for(h in 0:max.lag){                   
    tsplot(stats::lag(series1,-h), series2, xy.labels=FALSE, type='p', xlab=paste(name1,h,")",sep=""), ylab=name2, col=col, ...) 
     if (smooth==TRUE) 
